==> mobile_pos-1.0.1.tar.gz: lib/src/views/dispute/log_dispute.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/progress_dialog.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/dispute/add_bank_sheet.dart';
import 'package:mobile_pos/src/views/dispute/dispute_type_sheet.dart';

class LogDispute extends StatefulWidget {
  final Transaction model;
  const LogDispute({super.key, required this.model});

  @override
  State<LogDispute> createState() => _LogDisputeState();
}

class _LogDisputeState extends State<LogDispute> {
  final customerName = TextEditingController();
  final phoneController = TextEditingController();
  final disputeTypeController = TextEditingController();
  final discriptionController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        bottomNavigationBar: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              RavenPayButton(
                buttonText: "Raise Dispute",
                onPressed: () {
                  if (validate()) {
                    submitDispute();
                  }
                },
              ),
              const Gap(30)
            ],
          ),
        ),
        backgroundColor: pluginTheme.isLightTheme ? AppColors.lightGrey3 : null,
        body: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Gap(24),
              const RavenPayCloseButton(
                text: "",
                isArrow: true,
              ),
              const Gap(24),
              Text("Dispute Center", style: headling1.copyWith()),
              Text("Raise an issues and track your dispute status.",
                  style: subtitle.copyWith(fontWeight: FontWeight.w500)),
              const Gap(24),
              Expanded(
                child: SingleChildScrollView(
                    child: Column(
                  children: [
                    RavenPayTextField(
                      controller: customerName,
                      labelText: "Customer Name",
                      hintText: "Enter customer name",
                    ),
                    const Gap(20),
                    RavenPayTextField(
                      counterText: '',
                      maxLength: 11,
                      inputType: TextInputType.phone,
                      controller: phoneController,
                      isPhone: true,
                      labelText: "Customer Phone Number",
                    ),
                    const Gap(20),
                    RavenPayTextField(
                      labelText: "Dispute Type",
                      hintText: "Select dispute type",
                      onTap: () async {
                        var choice = await showRavenPayBottomSheet(context,
                            child: SelectDisputeTypeSheet());

                        if (choice != null) {
                          disputeTypeController.text = choice;
                        }
                      },
                      isDropdown: true,
                      controller: disputeTypeController,
                      readOnly: true,
                    ),
                    const Gap(20),
                    RavenPayTextField(
                      labelText: "Description",
                      controller: discriptionController,
                      minLines: 4,
                    ),
                    const Gap(24),
                    Row(
                      children: [
                        Expanded(
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Text("Add Customer Bank",
                                  style: subtitle.copyWith(
                                      fontSize: 14,
                                      color: pluginTheme.isLightTheme
                                          ? Colors.black
                                          : null)),
                              const Gap(4),
                              Text("Optional",
                                  style: subtitle.copyWith(
                                    fontWeight: FontWeight.w400,
                                    fontSize: 14,
                                  ))
                            ],
                          ),
                        ),
                        GestureDetector(
                          onTap: () {
                            if (validate()) {
                              showRavenPayBottomSheet(context,
                                  child: AddCustomerBank(
                                onDone: (bankName, accountNumber) {
                                  submitDispute(
                                      bankName: bankName,
                                      accountNumber: accountNumber);
                                },
                              ));
                            }
                          },
                          child: Container(
                              padding: const EdgeInsets.symmetric(
                                  horizontal: 12, vertical: 4),
                              decoration: BoxDecoration(
                                  borderRadius: BorderRadius.circular(12),
                                  color: pluginConfig.theme!.primaryColor
                                      .withOpacity(0.15)),
                              child: Row(
                                children: [
                                  Text("Select",
                                      style: bodyText.copyWith(fontSize: 12)),
                                  const Gap(2),
                                  Image.asset(
                                    loadAsset("ios_dropdown_icon.png"),
                                    color: pluginConfig.theme!.primaryColor,
                                    height: 14,
                                  )
                                ],
                              )),
                        )
                      ],
                    )
                  ],
                )),
              )
            ],
          ),
        ));
  }

  dynamic validate() {
    if (customerName.text.length < 2) {
      showSnack(context, "invalid customer name");
      return;
    }
    if (phoneController.text.length < 10) {
      showSnack(context, "invalid customer phone number");
      return;
    }
    if (disputeTypeController.text.length < 2) {
      showSnack(context, "please select dispute type");
      return;
    }
    if (discriptionController.text.length < 2) {
      showSnack(context, "provide a valid description");
      return;
    }
    return true;
  }

  submitDispute({String bankName = "", String accountNumber = ""}) async {
    showDialog(
        barrierDismissible: true,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Updating info...',
            ));
    final response = await ApiRequests.logDispute(
        transactionId: widget.model.id.toString(),
        customerName: customerName.text,
        customerPhone: phoneController.text,
        disputeType: disputeTypeController.text,
        description: discriptionController.text,
        bank: bankName,
        accountNumber: accountNumber,
        amount: widget.model.amount);
    logData(response);
    Navigator.pop(context);
    if (response['status'] == 'success') {
      widget.model.disputeStatus = 1;
      Navigator.pop(context);
    } else {
      showSnack(context, response['message']);
    }
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/dispute/log_dispute.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/progress_dialog.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/dispute/add_bank_sheet.dart';
import 'package:mobile_pos/src/views/dispute/dispute_type_sheet.dart';

class LogDispute extends StatefulWidget {
  final Transaction model;
  const LogDispute({super.key, required this.model});

  @override
  State<LogDispute> createState() => _LogDisputeState();
}

class _LogDisputeState extends State<LogDispute> {
  final customerName = TextEditingController();
  final phoneController = TextEditingController();
  final disputeTypeController = TextEditingController();
  final discriptionController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        bottomNavigationBar: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              RavenPayButton(
                buttonText: "Raise Dispute",
                onPressed: () {
                  if (validate()) {
                    submitDispute();
                  }
                },
              ),
              const Gap(30)
            ],
          ),
        ),
        backgroundColor: pluginTheme.isLightTheme ? AppColors.lightGrey3 : null,
        body: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Gap(24),
              const RavenPayCloseButton(
                text: "",
                isArrow: true,
              ),
              const Gap(24),
              Text("Dispute Center", style: headling1.copyWith()),
              Text("Raise an issues and track your dispute status.",
                  style: subtitle.copyWith(fontWeight: FontWeight.w500)),
              const Gap(24),
              Expanded(
                child: SingleChildScrollView(
                    child: Column(
                  children: [
                    RavenPayTextField(
                      controller: customerName,
                      labelText: "Customer Name",
                      hintText: "Enter customer name",
                    ),
                    const Gap(20),
                    RavenPayTextField(
                      counterText: '',
                      maxLength: 11,
                      inputType: TextInputType.phone,
                      controller: phoneController,
                      isPhone: true,
                      labelText: "Customer Phone Number",
                    ),
                    const Gap(20),
                    RavenPayTextField(
                      labelText: "Dispute Type",
                      hintText: "Select dispute type",
                      onTap: () async {
                        var choice = await showRavenPayBottomSheet(context,
                            child: SelectDisputeTypeSheet());

                        if (choice != null) {
                          disputeTypeController.text = choice;
                        }
                      },
                      isDropdown: true,
                      controller: disputeTypeController,
                      readOnly: true,
                    ),
                    const Gap(20),
                    RavenPayTextField(
                      labelText: "Description",
                      controller: discriptionController,
                      minLines: 4,
                    ),
                    const Gap(24),
                    Row(
                      children: [
                        Expanded(
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Text("Add Customer Bank",
                                  style: subtitle.copyWith(
                                      fontSize: 14,
                                      color: pluginTheme.isLightTheme
                                          ? Colors.black
                                          : null)),
                              const Gap(4),
                              Text("Optional",
                                  style: subtitle.copyWith(
                                    fontWeight: FontWeight.w400,
                                    fontSize: 14,
                                  ))
                            ],
                          ),
                        ),
                        GestureDetector(
                          onTap: () {
                            if (validate()) {
                              showRavenPayBottomSheet(context,
                                  child: AddCustomerBank(
                                onDone: (bankName, accountNumber) {
                                  submitDispute(
                                      bankName: bankName,
                                      accountNumber: accountNumber);
                                },
                              ));
                            }
                          },
                          child: Container(
                              padding: const EdgeInsets.symmetric(
                                  horizontal: 12, vertical: 4),
                              decoration: BoxDecoration(
                                  borderRadius: BorderRadius.circular(12),
                                  color: pluginConfig.theme!.primaryColor
                                      .withOpacity(0.15)),
                              child: Row(
                                children: [
                                  Text("Select",
                                      style: bodyText.copyWith(fontSize: 12)),
                                  const Gap(2),
                                  Image.asset(
                                    loadAsset("ios_dropdown_icon.png"),
                                    color: pluginConfig.theme!.primaryColor,
                                    height: 14,
                                  )
                                ],
                              )),
                        )
                      ],
                    )
                  ],
                )),
              )
            ],
          ),
        ));
  }

  dynamic validate() {
    if (customerName.text.length < 2) {
      showSnack(context, "invalid customer name");
      return;
    }
    if (phoneController.text.length < 10) {
      showSnack(context, "invalid customer phone number");
      return;
    }
    if (disputeTypeController.text.length < 2) {
      showSnack(context, "please select dispute type");
      return;
    }
    if (discriptionController.text.length < 2) {
      showSnack(context, "provide a valid description");
      return;
    }
    return true;
  }

  submitDispute({String bankName = "", String accountNumber = ""}) async {
    showDialog(
        barrierDismissible: true,
        context: context,
        builder: (BuildContext context) => const ProgressDialog(
              status: 'Updating info...',
            ));
    final response = await ApiRequests.logDispute(
        transactionId: widget.model.id.toString(),
        customerName: customerName.text,
        customerPhone: phoneController.text,
        disputeType: disputeTypeController.text,
        description: discriptionController.text,
        bank: bankName,
        accountNumber: accountNumber,
        amount: widget.model.amount ?? "0.0");
    logData(response);
    Navigator.pop(context);
    if (response['status'] == 'success') {
      widget.model.disputeStatus = 1;
      Navigator.pop(context);
    } else {
      showSnack(context, response['message']);
    }
  }
}
